package devmgr.api.model;

import devmgr.api.symbol.EventPriority;
import devmgr.api.symbol.MelEntry;

import javax.xml.bind.annotation.XmlRootElement;

/**
 * Author: khulques
 * Date: 1/13/14
 * Description - Extension class for SYMbol MelEntry.  Removes RawData field
 * and TimeStamp (long).  A new field occrredAt replaces timestamp.
 */
@XmlRootElement
public class MelEntryEx extends MelEntry implements Comparable<MelEntryEx>, Identifiable {
    private String description;
    private String location;

    @Override
    public String getId() {
        return Long.toString(getSequenceNumber());
    }

    public MelEntryEx() {
    }

    /**
     * @API_Spec_Description  A description of the event.
     */
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    /**
     * @API_Spec_Description  Set to "true" if the priority of the event is "critical".
     */
    public boolean isCritical() {
        return getPriority().equals(EventPriority.priorityCritical);
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof MelEntryEx)) return false;

        MelEntryEx that = (MelEntryEx) o;

        long thisSeq = getSequenceNumber();
        long thatSeq = that.getSequenceNumber();
        if (thisSeq != thatSeq) return false;

        long thisTimestamp = getTimeStamp();
        long thatTimestamp = getTimeStamp();
        if (thisTimestamp != thatTimestamp) return false;

        return true;
    }

    @Override
    public int hashCode() {
        long timestamp = getTimeStamp();
        long seq = getSequenceNumber();
        int result = (int) (timestamp ^ (timestamp >>> 32));
        result = 31 * result + (int) (seq ^ (seq >>> 32));
        return result;
    }

    /**
     * @API_Spec_Description  The location, or other identifying value, of the component associated
     * with this entry.
     */
    public String getLocation() {
        return this.location;
    }
    public void setLocation(String location) {
        this.location = location;
    }

    @Override
    public int compareTo(final MelEntryEx other) {
        return Long.compare(this.getSequenceNumber(), other.getSequenceNumber());
    }

    public static MelEntryEx fromMelEntry(MelEntry me) {
        MelEntryEx m = new MelEntryEx();
        m.setEventSourceController(me.getEventSourceController());
        m.setRawData(me.getRawData());
        m.setEventType(me.getEventType());
        m.setControlParams(me.getControlParams());
        m.setASC(me.getASC());
        m.setASCQ(me.getASCQ());
        m.setCategory(me.getCategory());
        m.setComponentLocation(me.getComponentLocation());
        m.setComponentType(me.getComponentType());
        m.setExtComponentLocation(me.getExtComponentLocation());
        m.setLocationValid(me.isLocationValid());
        m.setPriority(me.getPriority());
        m.setSenseKey(me.getSenseKey());
        m.setSequenceNumber(me.getSequenceNumber());
        m.setTimeStamp(me.getTimeStamp());
        return m;
    }
}
