package devmgr.api.rpc;

import devmgr.api.rpc.protocol.RPCAuthType;
import devmgr.api.rpc.protocol.RPCOpaqueAuth;
import devmgr.api.runtime.XdrMessage;

/**
 * This class implements a generator object for the NULL authentication
 * mechanism.
 */
public class RPCNullAuthGenerator 
implements RPCAuthGenerator
{
    private RPCOpaqueAuth m_NullAuth;

    /**
     * Constructor for null authentication objects.  Just creates a private
     * object that can be encoded onto XDR streams when necessary.
     */
    public RPCNullAuthGenerator()
    {
        // Initialize a private object for future use.
        m_NullAuth = new RPCOpaqueAuth();
        m_NullAuth.setType(RPCAuthType.AUTH_NONE);
        m_NullAuth.setInfo("");
    }

    /**
     * Return the "initial" authentication information for an RPC request
     * message.  We just return a local NULL authentication object that was
     * created at construction time.
     * @return RPCOpaqueAuth The initial authentication data for the message.
     */
    public RPCOpaqueAuth getInitialAuthData()
    {
        return m_NullAuth;
    }

    /**
     * Returns the "final" authentication information for the specified RPC
     * message.  Since NULL authentication data does not depend on the message
     * contents, this method just returns the same NULL authentication object
     * as was used in the initial call.
     * @param initial Initial authentication data used in the message.
     * @param msg Complete RPC message to be authenticated.
     * @return RPCOpaqueAuth The final authentication data for the message.
     */
    public RPCOpaqueAuth getFinalAuthData(RPCOpaqueAuth initial,
                                          XdrMessage msg)
    {
        return m_NullAuth;
    }
}
