package devmgr.api.runtime;

import java.util.HashMap;

public class UnionSpec
extends TypeSpec
{
    public boolean isVarLen;
    public HashMap<String, AlternateBinding> nameMap;
    public HashMap<Integer, AlternateBinding> caseMap;
    public String discrimName;
    public TypeSpec discrimType;
    public AlternateBinding[] alternates;
    public TypeBinding defaultBinding;
    public Class<?> cls;
    
    public
    UnionSpec(boolean varLen, String discName, TypeSpec discType, 
              AlternateBinding[] alts, Class<?> objClass)
    {
        this(varLen, discName, discType, null, null, alts, objClass);
    }
    
    public
    UnionSpec(boolean varLen, String discName, TypeSpec discType, 
              String defaultCaseLabel, TypeSpec defaultType,
              AlternateBinding[] alts, Class<?> objClass)
    {
        super(TypeSpec.TypeCode.UNION);
        
        isVarLen = varLen;
        discrimName = discName;
        discrimType = discType;
        alternates = alts;
        cls = objClass;
                
        if (defaultCaseLabel == null)
            defaultBinding = null;
        else
            defaultBinding = new TypeBinding(defaultCaseLabel, defaultType);
        
        // Build the map that we need for decode operations, when we're
        // processing an incoming alternate name and need the associated
        // alternate descriptor.
        nameMap = new HashMap<String, AlternateBinding>(alternates.length);
        for (int i = 0; i < alternates.length; i++)
        {
            if (alternates[i].itemName != null)
                nameMap.put(alternates[i].itemName, alternates[i]);
        }
        
        // Build the map that associates a discriminator case value
        // with the associated alternate descriptor.  We need this when
        // encoding, but also for validation of inbound data when decoding.
        caseMap = new HashMap<Integer, AlternateBinding>(alternates.length);
        for (int i = 0; i < alternates.length; i++)
            caseMap.put(alternates[i].caseValue, alternates[i]);
    }
}