package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure describes the characteristics of the controller's access volume, which is a special, virtual volume that is used to convey configuration operation requests to a controller. Although the access volume is presented by the storage array as a unit capable of processing standard block I/O requests, it is designed specifically to handle only configuration command transactions using the controller's UTM (Universal Transport Mechanism) protocol. It cannot be used for standard data storage applications. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(926)
public class AccessVolume implements Serializable {
	public AccessVolume() {
	}

	/** True if the access volume feature (and thus the UTM command transfer capability) is enabled, or false if it is disabled. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the access volume feature (and thus the UTM command transfer capability) is enabled, or false if it is disabled." , required = true)
	@XmlElement(required = true)
	private boolean enabled;

	/** @return True if the access volume feature (and thus the UTM command transfer capability) is enabled, or false if it is disabled. */
	public boolean isEnabled() {
		return this.enabled;
	}
	/** @param x True if the access volume feature (and thus the UTM command transfer capability) is enabled, or false if it is disabled. */
	public void setEnabled(boolean x) {
		this.enabled = x;
	}

	/** An identifier value for the AccessVolume object. This will generally correspond to the logical unit number (LUN) that is used to access the volume for UTM protocol command transactions. */
	@io.swagger.annotations.ApiModelProperty(value ="An identifier value for the AccessVolume object. This will generally correspond to the logical unit number (LUN) that is used to access the volume for UTM protocol command transactions." , required = true)
	@XmlElement(required = true)
	private int volumeHandle;

	/** @return An identifier value for the AccessVolume object. This will generally correspond to the logical unit number (LUN) that is used to access the volume for UTM protocol command transactions. */
	public int getVolumeHandle() {
		return this.volumeHandle;
	}
	/** @param x An identifier value for the AccessVolume object. This will generally correspond to the logical unit number (LUN) that is used to access the volume for UTM protocol command transactions. */
	public void setVolumeHandle(int x) {
		this.volumeHandle = x;
	}

	/** The (simulated) capacity of the AccessVolume maintained by the controller. Since there is essentially no true data storage capacity present for an AccessVolume, this value is used to determine the block addressing limit of the unit, which is an important aspect of the UTM command transfer protocol. */
	@io.swagger.annotations.ApiModelProperty(value ="The (simulated) capacity of the AccessVolume maintained by the controller. Since there is essentially no true data storage capacity present for an AccessVolume, this value is used to determine the block addressing limit of the unit, which is an important aspect of the UTM command transfer protocol." , required = true)
	@XmlElement(required = true)
	private long capacity;

	/** @return The (simulated) capacity of the AccessVolume maintained by the controller. Since there is essentially no true data storage capacity present for an AccessVolume, this value is used to determine the block addressing limit of the unit, which is an important aspect of the UTM command transfer protocol. */
	public long getCapacity() {
		return this.capacity;
	}
	/** @param x The (simulated) capacity of the AccessVolume maintained by the controller. Since there is essentially no true data storage capacity present for an AccessVolume, this value is used to determine the block addressing limit of the unit, which is an important aspect of the UTM command transfer protocol. */
	public void setCapacity(long x) {
		this.capacity = x;
	}

	/** The identifier value for this AccessVolume. Other objects may use this reference value to refer to the AccessVolume. */
	@io.swagger.annotations.ApiModelProperty(value ="The identifier value for this AccessVolume. Other objects may use this reference value to refer to the AccessVolume." , required = true)
	@XmlElement(required = true)
	private String accessVolumeRef;

	/** @return The identifier value for this AccessVolume. Other objects may use this reference value to refer to the AccessVolume. */
	public String getAccessVolumeRef() {
		return this.accessVolumeRef;
	}
	/** @param x The identifier value for this AccessVolume. Other objects may use this reference value to refer to the AccessVolume. */
	public void setAccessVolumeRef(String x) {
		this.accessVolumeRef = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private String reserved1;

	/** @return Reserved for future use. */
	public String getReserved1() {
		return this.reserved1;
	}
	/** @param x Reserved for future use. */
	public void setReserved1(String x) {
		this.reserved1 = x;
	}
}
