package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** An enumeration that includes the possible Port ID TLV sub-types as specified in IEEE specification 802.1ab. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(79)
public enum EnhEthPortIDSubtype implements Serializable {
		/** The Port ID TLV subtype is unknown. */
		unk(0),
		/** The Port ID TLV subtype is the Interface Alias - If Alias (IETF RFC 2863). */
		intfAlias(1),
		/** The Port ID TLV subtype is the Port Component - EntPhysicalAlias when entPhysicalClass has a value 'port(10)' or 'backplane(4)' (IETF RFC 2737). */
		portComp(2),
		/** The Port ID TLV subtype is the MAC Address - IEEE Std 802-2001. */
		macAddr(3),
		/** The Port ID TLV subtype is the Network Address - an octet string that identifies a particular network address family and an associated network address that are encoded in network octet order. An IP address, for example, would be encoded with the first octet containing the IANA Address Family Numbers enumeration value for the specific address type and octets 2 through n containing the address value (for example, the encoding for C0-A8-FE-0A would indicate the IP version 4 address 192.168.254.10). */
		ntwkAddr(4),
		/** The Port ID TLV subtype is the Interface Name - if Name (IETF RFC 2863). */
		intfName(5),
		/** The Port ID TLV subtype is the Agent circuit ID - (IETF RFC 3046) */
		agentCircuit(6),
		/** The Port ID TLV subtype is Locally Assigned - an alpha-numeric string and is locally assigned. */
		local(7),
		__UNDEFINED(464378545);

		public final int value;

		private EnhEthPortIDSubtype(int v) {
			this.value = v;
		}
}
