package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used to convey a feature-enabling key to the storage array controller so that a "premium" feature can be activated. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(446)
public class FeatureKey implements Serializable {
	public FeatureKey() {
	}

	/** An internal indication of the version of the feature key. */
	@io.swagger.annotations.ApiModelProperty(value ="An internal indication of the version of the feature key." , required = true)
	@XmlElement(required = true)
	private int keyVersion;

	/** @return An internal indication of the version of the feature key. */
	public int getKeyVersion() {
		return this.keyVersion;
	}
	/** @param x An internal indication of the version of the feature key. */
	public void setKeyVersion(int x) {
		this.keyVersion = x;
	}

	/** The capability code for the feature that is to be enabled by this key. */
	@io.swagger.annotations.ApiModelProperty(value ="The capability code for the feature that is to be enabled by this key." , required = true)
	@XmlElement(required = true)
	private Capability capability = Capability.__UNDEFINED;

	/** @return The capability code for the feature that is to be enabled by this key. */
	public Capability getCapability() {
		return this.capability;
	}
	/** @param x The capability code for the feature that is to be enabled by this key. */
	public void setCapability(Capability x) {
		this.capability = x;
	}

	/** This field contains a unique identifier maintained by SAFE for use by storage management software. Storage management software uses this data to enable SAFE features and perform Feature Bundle migration. */
	@io.swagger.annotations.ApiModelProperty(value ="This field contains a unique identifier maintained by SAFE for use by storage management software. Storage management software uses this data to enable SAFE features and perform Feature Bundle migration." , required = true)
	@XmlElement(required = true)
	private SAIdentifier saId;

	/** @return This field contains a unique identifier maintained by SAFE for use by storage management software. Storage management software uses this data to enable SAFE features and perform Feature Bundle migration. */
	public SAIdentifier getSaId() {
		return this.saId;
	}
	/** @param x This field contains a unique identifier maintained by SAFE for use by storage management software. Storage management software uses this data to enable SAFE features and perform Feature Bundle migration. */
	public void setSaId(SAIdentifier x) {
		this.saId = x;
	}

	/** A computed message digest that verifies the authenticity of this feature key. */
	@io.swagger.annotations.ApiModelProperty(value ="A computed message digest that verifies the authenticity of this feature key." , required = true)
	@XmlElement(required = true)
	private String digest;

	/** @return A computed message digest that verifies the authenticity of this feature key. */
	public String getDigest() {
		return this.digest;
	}
	/** @param x A computed message digest that verifies the authenticity of this feature key. */
	public void setDigest(String x) {
		this.digest = x;
	}

	/** The numeric limit for this specific feature. A zero value for a limit indicates a feature that is fully enabled and does not support tiers such as RAID 6. */
	@io.swagger.annotations.ApiModelProperty(value ="The numeric limit for this specific feature. A zero value for a limit indicates a feature that is fully enabled and does not support tiers such as RAID 6." , required = true)
	@XmlElement(required = true)
	private int limit;

	/** @return The numeric limit for this specific feature. A zero value for a limit indicates a feature that is fully enabled and does not support tiers such as RAID 6. */
	public int getLimit() {
		return this.limit;
	}
	/** @param x The numeric limit for this specific feature. A zero value for a limit indicates a feature that is fully enabled and does not support tiers such as RAID 6. */
	public void setLimit(int x) {
		this.limit = x;
	}

	/** The duration before this feature is expired. An evaluation period is specified in days. A zero value for an evaluation period indicates a permanent license that has been purchased. */
	@io.swagger.annotations.ApiModelProperty(value ="The duration before this feature is expired. An evaluation period is specified in days. A zero value for an evaluation period indicates a permanent license that has been purchased." , required = true)
	@XmlElement(required = true)
	private int duration;

	/** @return The duration before this feature is expired. An evaluation period is specified in days. A zero value for an evaluation period indicates a permanent license that has been purchased. */
	public int getDuration() {
		return this.duration;
	}
	/** @param x The duration before this feature is expired. An evaluation period is specified in days. A zero value for an evaluation period indicates a permanent license that has been purchased. */
	public void setDuration(int x) {
		this.duration = x;
	}

	/** For an additive license this will be the Key ID. */
	@io.swagger.annotations.ApiModelProperty(value ="For an additive license this will be the Key ID." , required = true)
	@XmlElement(required = true)
	private String keyId;

	/** @return For an additive license this will be the Key ID. */
	public String getKeyId() {
		return this.keyId;
	}
	/** @param x For an additive license this will be the Key ID. */
	public void setKeyId(String x) {
		this.keyId = x;
	}

	/** The supported Feature Bundle ID. When not in use this value will be zero. */
	@io.swagger.annotations.ApiModelProperty(value ="The supported Feature Bundle ID. When not in use this value will be zero." , required = true)
	@XmlElement(required = true)
	private int supportedFeatureBundleId;

	/** @return The supported Feature Bundle ID. When not in use this value will be zero. */
	public int getSupportedFeatureBundleId() {
		return this.supportedFeatureBundleId;
	}
	/** @param x The supported Feature Bundle ID. When not in use this value will be zero. */
	public void setSupportedFeatureBundleId(int x) {
		this.supportedFeatureBundleId = x;
	}
}
