package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure contains data collected for a single flash cache analytics item. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(332)
public class FlashCacheAnalyticsItem implements Serializable {
	public FlashCacheAnalyticsItem() {
	}

	/** The cache size in Gigabytes. */
	@io.swagger.annotations.ApiModelProperty(value ="The cache size in Gigabytes." , required = true)
	@XmlElement(required = true)
	private int cacheSize;

	/** @return The cache size in Gigabytes. */
	public int getCacheSize() {
		return this.cacheSize;
	}
	/** @param x The cache size in Gigabytes. */
	public void setCacheSize(int x) {
		this.cacheSize = x;
	}

	/** The flash cache hit percentage times 100. This is calculated using totalFlashCacheReads/(totalBaseWrites + totalBaseReads + totalFlashCacheReads). */
	@io.swagger.annotations.ApiModelProperty(value ="The flash cache hit percentage times 100. This is calculated using totalFlashCacheReads/(totalBaseWrites + totalBaseReads + totalFlashCacheReads)." , required = true)
	@XmlElement(required = true)
	private int cacheHitPct;

	/** @return The flash cache hit percentage times 100. This is calculated using totalFlashCacheReads/(totalBaseWrites + totalBaseReads + totalFlashCacheReads). */
	public int getCacheHitPct() {
		return this.cacheHitPct;
	}
	/** @param x The flash cache hit percentage times 100. This is calculated using totalFlashCacheReads/(totalBaseWrites + totalBaseReads + totalFlashCacheReads). */
	public void setCacheHitPct(int x) {
		this.cacheHitPct = x;
	}

	/** Host writes sent to volume(s) enabled for flash cache and serviced from either HDD or Primary Cache. */
	@io.swagger.annotations.ApiModelProperty(value ="Host writes sent to volume(s) enabled for flash cache and serviced from either HDD or Primary Cache." , required = true)
	@XmlElement(required = true)
	private long totalBaseWrites;

	/** @return Host writes sent to volume(s) enabled for flash cache and serviced from either HDD or Primary Cache. */
	public long getTotalBaseWrites() {
		return this.totalBaseWrites;
	}
	/** @param x Host writes sent to volume(s) enabled for flash cache and serviced from either HDD or Primary Cache. */
	public void setTotalBaseWrites(long x) {
		this.totalBaseWrites = x;
	}

	/** Write latency associated with HDD or DRAM access (in micro-seconds) for the volume(s) enabled for flash cache. */
	@io.swagger.annotations.ApiModelProperty(value ="Write latency associated with HDD or DRAM access (in micro-seconds) for the volume(s) enabled for flash cache." , required = true)
	@XmlElement(required = true)
	private long totalBaseWriteLatency;

	/** @return Write latency associated with HDD or DRAM access (in micro-seconds) for the volume(s) enabled for flash cache. */
	public long getTotalBaseWriteLatency() {
		return this.totalBaseWriteLatency;
	}
	/** @param x Write latency associated with HDD or DRAM access (in micro-seconds) for the volume(s) enabled for flash cache. */
	public void setTotalBaseWriteLatency(long x) {
		this.totalBaseWriteLatency = x;
	}

	/** Read latency associated with HDD or DRAM access (in micro-seconds) for the volume(s) enabled for flash cache. */
	@io.swagger.annotations.ApiModelProperty(value ="Read latency associated with HDD or DRAM access (in micro-seconds) for the volume(s) enabled for flash cache." , required = true)
	@XmlElement(required = true)
	private long totalBaseReadLatency;

	/** @return Read latency associated with HDD or DRAM access (in micro-seconds) for the volume(s) enabled for flash cache. */
	public long getTotalBaseReadLatency() {
		return this.totalBaseReadLatency;
	}
	/** @param x Read latency associated with HDD or DRAM access (in micro-seconds) for the volume(s) enabled for flash cache. */
	public void setTotalBaseReadLatency(long x) {
		this.totalBaseReadLatency = x;
	}

	/** Host reads sent to volume(s) enabled for flash cache and serviced from either HDD or Primary Cache. */
	@io.swagger.annotations.ApiModelProperty(value ="Host reads sent to volume(s) enabled for flash cache and serviced from either HDD or Primary Cache." , required = true)
	@XmlElement(required = true)
	private long totalBaseReads;

	/** @return Host reads sent to volume(s) enabled for flash cache and serviced from either HDD or Primary Cache. */
	public long getTotalBaseReads() {
		return this.totalBaseReads;
	}
	/** @param x Host reads sent to volume(s) enabled for flash cache and serviced from either HDD or Primary Cache. */
	public void setTotalBaseReads(long x) {
		this.totalBaseReads = x;
	}

	/** Host reads sent to volume(s) enabled for flash cache and serviced from flash cache (SSD or Primary Cache). */
	@io.swagger.annotations.ApiModelProperty(value ="Host reads sent to volume(s) enabled for flash cache and serviced from flash cache (SSD or Primary Cache)." , required = true)
	@XmlElement(required = true)
	private long totalFlashCacheReads;

	/** @return Host reads sent to volume(s) enabled for flash cache and serviced from flash cache (SSD or Primary Cache). */
	public long getTotalFlashCacheReads() {
		return this.totalFlashCacheReads;
	}
	/** @param x Host reads sent to volume(s) enabled for flash cache and serviced from flash cache (SSD or Primary Cache). */
	public void setTotalFlashCacheReads(long x) {
		this.totalFlashCacheReads = x;
	}

	/** Read latency associated with flash cache access (in micro-seconds) for the volume(s) enabled for flash cache. */
	@io.swagger.annotations.ApiModelProperty(value ="Read latency associated with flash cache access (in micro-seconds) for the volume(s) enabled for flash cache." , required = true)
	@XmlElement(required = true)
	private long totalFlashCacheReadLatency;

	/** @return Read latency associated with flash cache access (in micro-seconds) for the volume(s) enabled for flash cache. */
	public long getTotalFlashCacheReadLatency() {
		return this.totalFlashCacheReadLatency;
	}
	/** @param x Read latency associated with flash cache access (in micro-seconds) for the volume(s) enabled for flash cache. */
	public void setTotalFlashCacheReadLatency(long x) {
		this.totalFlashCacheReadLatency = x;
	}
}
