package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure contains the various data elements that comprise an InfiniBand I/O controller profile */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(407)
public class IbIocProfile implements Serializable {
	public IbIocProfile() {
	}

	/** The EUI-64 GUID used to uniquely identify the I/O controller. */
	@io.swagger.annotations.ApiModelProperty(value ="The EUI-64 GUID used to uniquely identify the I/O controller." , required = true)
	@XmlElement(required = true)
	private String iocGuid;

	/** @return The EUI-64 GUID used to uniquely identify the I/O controller. */
	public String getIocGuid() {
		return this.iocGuid;
	}
	/** @param x The EUI-64 GUID used to uniquely identify the I/O controller. */
	public void setIocGuid(String x) {
		this.iocGuid = x;
	}

	/** The I/O controller vendor ID in IEEE format. */
	@io.swagger.annotations.ApiModelProperty(value ="The I/O controller vendor ID in IEEE format." , required = true)
	@XmlElement(required = true)
	private String vendorId;

	/** @return The I/O controller vendor ID in IEEE format. */
	public String getVendorId() {
		return this.vendorId;
	}
	/** @param x The I/O controller vendor ID in IEEE format. */
	public void setVendorId(String x) {
		this.vendorId = x;
	}

	/** A number assigned by vendor to identify the type of I/O controller */
	@io.swagger.annotations.ApiModelProperty(value ="A number assigned by vendor to identify the type of I/O controller" , required = true)
	@XmlElement(required = true)
	private long ioDeviceId;

	/** @return A number assigned by vendor to identify the type of I/O controller */
	public long getIoDeviceId() {
		return this.ioDeviceId;
	}
	/** @param x A number assigned by vendor to identify the type of I/O controller */
	public void setIoDeviceId(long x) {
		this.ioDeviceId = x;
	}

	/** A number assigned by the vendor to identify the device version. */
	@io.swagger.annotations.ApiModelProperty(value ="A number assigned by the vendor to identify the device version." , required = true)
	@XmlElement(required = true)
	private int deviceVersion;

	/** @return A number assigned by the vendor to identify the device version. */
	public int getDeviceVersion() {
		return this.deviceVersion;
	}
	/** @param x A number assigned by the vendor to identify the device version. */
	public void setDeviceVersion(int x) {
		this.deviceVersion = x;
	}

	/** The ID of the enclosure vendor in IEEE format, or else all zeros if there is no vendor ID. */
	@io.swagger.annotations.ApiModelProperty(value ="The ID of the enclosure vendor in IEEE format, or else all zeros if there is no vendor ID." , required = true)
	@XmlElement(required = true)
	private String subsystemVendorId;

	/** @return The ID of the enclosure vendor in IEEE format, or else all zeros if there is no vendor ID. */
	public String getSubsystemVendorId() {
		return this.subsystemVendorId;
	}
	/** @param x The ID of the enclosure vendor in IEEE format, or else all zeros if there is no vendor ID. */
	public void setSubsystemVendorId(String x) {
		this.subsystemVendorId = x;
	}

	/** A number identifying the subsystem where the I/O controller resides. */
	@io.swagger.annotations.ApiModelProperty(value ="A number identifying the subsystem where the I/O controller resides." , required = true)
	@XmlElement(required = true)
	private long subsystemId;

	/** @return A number identifying the subsystem where the I/O controller resides. */
	public long getSubsystemId() {
		return this.subsystemId;
	}
	/** @param x A number identifying the subsystem where the I/O controller resides. */
	public void setSubsystemId(long x) {
		this.subsystemId = x;
	}

	/** The I/O class of the controller. 0x0000 -0xFFFE is reserved for I/O classes encompassed by the InfiniBand architecture. 0xFFFF is vendor-specific. */
	@io.swagger.annotations.ApiModelProperty(value ="The I/O class of the controller. 0x0000 -0xFFFE is reserved for I/O classes encompassed by the InfiniBand architecture. 0xFFFF is vendor-specific." , required = true)
	@XmlElement(required = true)
	private int ioClass;

	/** @return The I/O class of the controller. 0x0000 -0xFFFE is reserved for I/O classes encompassed by the InfiniBand architecture. 0xFFFF is vendor-specific. */
	public int getIoClass() {
		return this.ioClass;
	}
	/** @param x The I/O class of the controller. 0x0000 -0xFFFE is reserved for I/O classes encompassed by the InfiniBand architecture. 0xFFFF is vendor-specific. */
	public void setIoClass(int x) {
		this.ioClass = x;
	}

	/** The I/O sub-class of the controller. 0x0000 -0xFFFE is reserved for I/O sub-classes encompassed by the InfiniBand architecture. 0xFFFF is vendor-specific. */
	@io.swagger.annotations.ApiModelProperty(value ="The I/O sub-class of the controller. 0x0000 -0xFFFE is reserved for I/O sub-classes encompassed by the InfiniBand architecture. 0xFFFF is vendor-specific." , required = true)
	@XmlElement(required = true)
	private int ioSubclass;

	/** @return The I/O sub-class of the controller. 0x0000 -0xFFFE is reserved for I/O sub-classes encompassed by the InfiniBand architecture. 0xFFFF is vendor-specific. */
	public int getIoSubclass() {
		return this.ioSubclass;
	}
	/** @param x The I/O sub-class of the controller. 0x0000 -0xFFFE is reserved for I/O sub-classes encompassed by the InfiniBand architecture. 0xFFFF is vendor-specific. */
	public void setIoSubclass(int x) {
		this.ioSubclass = x;
	}

	/** The I/O protocol of the controller. 0x0000 -0xFFFE is reserved for I/O protocols encompassed by the InfiniBand architecture. 0xFFFF is vendor-specific. */
	@io.swagger.annotations.ApiModelProperty(value ="The I/O protocol of the controller. 0x0000 -0xFFFE is reserved for I/O protocols encompassed by the InfiniBand architecture. 0xFFFF is vendor-specific." , required = true)
	@XmlElement(required = true)
	private int protocol;

	/** @return The I/O protocol of the controller. 0x0000 -0xFFFE is reserved for I/O protocols encompassed by the InfiniBand architecture. 0xFFFF is vendor-specific. */
	public int getProtocol() {
		return this.protocol;
	}
	/** @param x The I/O protocol of the controller. 0x0000 -0xFFFE is reserved for I/O protocols encompassed by the InfiniBand architecture. 0xFFFF is vendor-specific. */
	public void setProtocol(int x) {
		this.protocol = x;
	}

	/** The protocol version (protocol-specific). */
	@io.swagger.annotations.ApiModelProperty(value ="The protocol version (protocol-specific)." , required = true)
	@XmlElement(required = true)
	private int protocolVersion;

	/** @return The protocol version (protocol-specific). */
	public int getProtocolVersion() {
		return this.protocolVersion;
	}
	/** @param x The protocol version (protocol-specific). */
	public void setProtocolVersion(int x) {
		this.protocolVersion = x;
	}

	/** The maximum depth of the Send Message Queue. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum depth of the Send Message Queue." , required = true)
	@XmlElement(required = true)
	private int sendMessageQueueDepth;

	/** @return The maximum depth of the Send Message Queue. */
	public int getSendMessageQueueDepth() {
		return this.sendMessageQueueDepth;
	}
	/** @param x The maximum depth of the Send Message Queue. */
	public void setSendMessageQueueDepth(int x) {
		this.sendMessageQueueDepth = x;
	}

	/** The maximum depth of the per-channel RDMA Read Queue */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum depth of the per-channel RDMA Read Queue" , required = true)
	@XmlElement(required = true)
	private short rdmaReadQueueDepth;

	/** @return The maximum depth of the per-channel RDMA Read Queue */
	public short getRdmaReadQueueDepth() {
		return this.rdmaReadQueueDepth;
	}
	/** @param x The maximum depth of the per-channel RDMA Read Queue */
	public void setRdmaReadQueueDepth(short x) {
		this.rdmaReadQueueDepth = x;
	}

	/** The maximum size of Send Messages in bytes. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum size of Send Messages in bytes." , required = true)
	@XmlElement(required = true)
	private long sendMessageSize;

	/** @return The maximum size of Send Messages in bytes. */
	public long getSendMessageSize() {
		return this.sendMessageSize;
	}
	/** @param x The maximum size of Send Messages in bytes. */
	public void setSendMessageSize(long x) {
		this.sendMessageSize = x;
	}

	/** The maximum size of outbound RDMA transfers initiated by the controller. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum size of outbound RDMA transfers initiated by the controller." , required = true)
	@XmlElement(required = true)
	private long rdmaTransferSize;

	/** @return The maximum size of outbound RDMA transfers initiated by the controller. */
	public long getRdmaTransferSize() {
		return this.rdmaTransferSize;
	}
	/** @param x The maximum size of outbound RDMA transfers initiated by the controller. */
	public void setRdmaTransferSize(long x) {
		this.rdmaTransferSize = x;
	}

	/** Supported operation types of this controller.: Bit 0 on = Send Messages to IOCs Bit 1 on = Send Messages from IOCs Bit 2 on = RDMA Read Requests to IOCs Bit 3 on = RDMA Read Requests from IOCs Bit 4 on = RDMA Write Requests to IOCs Bit 5 on = RDMA Write Requests from IOCs Bit 6 on = Atomic operations to IOCs Bit 7 on = Atomic operations from IOCs */
	@io.swagger.annotations.ApiModelProperty(value ="Supported operation types of this controller.: Bit 0 on = Send Messages to IOCs Bit 1 on = Send Messages from IOCs Bit 2 on = RDMA Read Requests to IOCs Bit 3 on = RDMA Read Requests from IOCs Bit 4 on = RDMA Write Requests to IOCs Bit 5 on = RDMA Write Requests from IOCs Bit 6 on = Atomic operations to IOCs Bit 7 on = Atomic operations from IOCs" , required = true)
	@XmlElement(required = true)
	private short controllerOpsCapabilityMask;

	/** @return Supported operation types of this controller.: Bit 0 on = Send Messages to IOCs Bit 1 on = Send Messages from IOCs Bit 2 on = RDMA Read Requests to IOCs Bit 3 on = RDMA Read Requests from IOCs Bit 4 on = RDMA Write Requests to IOCs Bit 5 on = RDMA Write Requests from IOCs Bit 6 on = Atomic operations to IOCs Bit 7 on = Atomic operations from IOCs */
	public short getControllerOpsCapabilityMask() {
		return this.controllerOpsCapabilityMask;
	}
	/** @param x Supported operation types of this controller.: Bit 0 on = Send Messages to IOCs Bit 1 on = Send Messages from IOCs Bit 2 on = RDMA Read Requests to IOCs Bit 3 on = RDMA Read Requests from IOCs Bit 4 on = RDMA Write Requests to IOCs Bit 5 on = RDMA Write Requests from IOCs Bit 6 on = Atomic operations to IOCs Bit 7 on = Atomic operations from IOCs */
	public void setControllerOpsCapabilityMask(short x) {
		this.controllerOpsCapabilityMask = x;
	}

	/** The number of entries in the service entries table */
	@io.swagger.annotations.ApiModelProperty(value ="The number of entries in the service entries table" , required = true)
	@XmlElement(required = true)
	private short serviceEntries;

	/** @return The number of entries in the service entries table */
	public short getServiceEntries() {
		return this.serviceEntries;
	}
	/** @param x The number of entries in the service entries table */
	public void setServiceEntries(short x) {
		this.serviceEntries = x;
	}

	/** A UTF-8 encoded string for identifying the controller to user. */
	@io.swagger.annotations.ApiModelProperty(value ="A UTF-8 encoded string for identifying the controller to user." , required = true)
	@XmlElement(required = true)
	private String idString;

	/** @return A UTF-8 encoded string for identifying the controller to user. */
	public String getIdString() {
		return this.idString;
	}
	/** @param x A UTF-8 encoded string for identifying the controller to user. */
	public void setIdString(String x) {
		this.idString = x;
	}
}
