package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure provides iSCSI protocol statistical data in the context of an iSCSI target. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(904)
public class IscsiTargetStatistics implements Serializable {
	public IscsiTargetStatistics() {
	}

	/** A reference to the target with which the statistics are associated. */
	@io.swagger.annotations.ApiModelProperty(value ="A reference to the target with which the statistics are associated." , required = true)
	@XmlElement(required = true)
	private String target;

	/** @return A reference to the target with which the statistics are associated. */
	public String getTarget() {
		return this.target;
	}
	/** @param x A reference to the target with which the statistics are associated. */
	public void setTarget(String x) {
		this.target = x;
	}

	/** The count of successful iSCSI logins to the target. */
	@io.swagger.annotations.ApiModelProperty(value ="The count of successful iSCSI logins to the target." , required = true)
	@XmlElement(required = true)
	private long successfulLogins;

	/** @return The count of successful iSCSI logins to the target. */
	public long getSuccessfulLogins() {
		return this.successfulLogins;
	}
	/** @param x The count of successful iSCSI logins to the target. */
	public void setSuccessfulLogins(long x) {
		this.successfulLogins = x;
	}

	/** The number of times an iSCSI login attempt to or from the target failed. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of times an iSCSI login attempt to or from the target failed." , required = true)
	@XmlElement(required = true)
	private long loginFailures;

	/** @return The number of times an iSCSI login attempt to or from the target failed. */
	public long getLoginFailures() {
		return this.loginFailures;
	}
	/** @param x The number of times an iSCSI login attempt to or from the target failed. */
	public void setLoginFailures(long x) {
		this.loginFailures = x;
	}

	/** The number of times an initiator login authentication attempt was accepted by the target. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of times an initiator login authentication attempt was accepted by the target." , required = true)
	@XmlElement(required = true)
	private long successfulLoginAuthentications;

	/** @return The number of times an initiator login authentication attempt was accepted by the target. */
	public long getSuccessfulLoginAuthentications() {
		return this.successfulLoginAuthentications;
	}
	/** @param x The number of times an initiator login authentication attempt was accepted by the target. */
	public void setSuccessfulLoginAuthentications(long x) {
		this.successfulLoginAuthentications = x;
	}

	/** The number of times an initiator login authentication attempt was rejected by the target. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of times an initiator login authentication attempt was rejected by the target." , required = true)
	@XmlElement(required = true)
	private long authenticationLoginFailures;

	/** @return The number of times an initiator login authentication attempt was rejected by the target. */
	public long getAuthenticationLoginFailures() {
		return this.authenticationLoginFailures;
	}
	/** @param x The number of times an initiator login authentication attempt was rejected by the target. */
	public void setAuthenticationLoginFailures(long x) {
		this.authenticationLoginFailures = x;
	}

	/** The number of iSCSI PDUs processed by the target that experienced no errors of any sort. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of iSCSI PDUs processed by the target that experienced no errors of any sort." , required = true)
	@XmlElement(required = true)
	private long errorFreePdus;

	/** @return The number of iSCSI PDUs processed by the target that experienced no errors of any sort. */
	public long getErrorFreePdus() {
		return this.errorFreePdus;
	}
	/** @param x The number of iSCSI PDUs processed by the target that experienced no errors of any sort. */
	public void setErrorFreePdus(long x) {
		this.errorFreePdus = x;
	}

	/** The number of iSCSI PDUs processed by the target that experienced protocol errors. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of iSCSI PDUs processed by the target that experienced protocol errors." , required = true)
	@XmlElement(required = true)
	private long protocolErrorPdus;

	/** @return The number of iSCSI PDUs processed by the target that experienced protocol errors. */
	public long getProtocolErrorPdus() {
		return this.protocolErrorPdus;
	}
	/** @param x The number of iSCSI PDUs processed by the target that experienced protocol errors. */
	public void setProtocolErrorPdus(long x) {
		this.protocolErrorPdus = x;
	}

	/** The number of iSCSI PDUs received by the target having header digest errors. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of iSCSI PDUs received by the target having header digest errors." , required = true)
	@XmlElement(required = true)
	private long headerDigestErrors;

	/** @return The number of iSCSI PDUs received by the target having header digest errors. */
	public long getHeaderDigestErrors() {
		return this.headerDigestErrors;
	}
	/** @param x The number of iSCSI PDUs received by the target having header digest errors. */
	public void setHeaderDigestErrors(long x) {
		this.headerDigestErrors = x;
	}

	/** The number of iSCSI PDUs received by the target having data digest errors. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of iSCSI PDUs received by the target having data digest errors." , required = true)
	@XmlElement(required = true)
	private long dataDigestErrors;

	/** @return The number of iSCSI PDUs received by the target having data digest errors. */
	public long getDataDigestErrors() {
		return this.dataDigestErrors;
	}
	/** @param x The number of iSCSI PDUs received by the target having data digest errors. */
	public void setDataDigestErrors(long x) {
		this.dataDigestErrors = x;
	}

	/** The number of iSCSI sessions for the target that terminated abnormally, either by administrative action or due to firmware-detected error. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of iSCSI sessions for the target that terminated abnormally, either by administrative action or due to firmware-detected error." , required = true)
	@XmlElement(required = true)
	private long sessionFailures;

	/** @return The number of iSCSI sessions for the target that terminated abnormally, either by administrative action or due to firmware-detected error. */
	public long getSessionFailures() {
		return this.sessionFailures;
	}
	/** @param x The number of iSCSI sessions for the target that terminated abnormally, either by administrative action or due to firmware-detected error. */
	public void setSessionFailures(long x) {
		this.sessionFailures = x;
	}

	/** The number of iSCSI connections for the target that terminated abnormally, either by administrative action or due to firmware-detected error. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of iSCSI connections for the target that terminated abnormally, either by administrative action or due to firmware-detected error." , required = true)
	@XmlElement(required = true)
	private long connectionFailures;

	/** @return The number of iSCSI connections for the target that terminated abnormally, either by administrative action or due to firmware-detected error. */
	public long getConnectionFailures() {
		return this.connectionFailures;
	}
	/** @param x The number of iSCSI connections for the target that terminated abnormally, either by administrative action or due to firmware-detected error. */
	public void setConnectionFailures(long x) {
		this.connectionFailures = x;
	}
}
