package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used to identify the physical location of a particular physical element. It includes a reference to the tray that contains the element, as well as the element's slot location within the tray. For physical elements that reside in well-defined slot positions within a tray, such as controllers, and drives, the slot indicator will always be directly correlated with the physical slot position. However, for certain other elements, the slot identifier is simply an ordinal number that distinguishes between different elements of the same type. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(770)
public class Location implements Serializable {
	public Location() {
	}

	/** The TrayRef reference value of the tray object in which the component resides. */
	@io.swagger.annotations.ApiModelProperty(value ="The TrayRef reference value of the tray object in which the component resides." , required = true)
	@XmlElement(required = true)
	private String trayRef;

	/** @return The TrayRef reference value of the tray object in which the component resides. */
	public String getTrayRef() {
		return this.trayRef;
	}
	/** @param x The TrayRef reference value of the tray object in which the component resides. */
	public void setTrayRef(String x) {
		this.trayRef = x;
	}

	/** The slot identifier, or ordinal identifier, of the component within its physical tray. */
	@io.swagger.annotations.ApiModelProperty(value ="The slot identifier, or ordinal identifier, of the component within its physical tray." , required = true)
	@XmlElement(required = true)
	private int slot;

	/** @return The slot identifier, or ordinal identifier, of the component within its physical tray. */
	public int getSlot() {
		return this.slot;
	}
	/** @param x The slot identifier, or ordinal identifier, of the component within its physical tray. */
	public void setSlot(int x) {
		this.slot = x;
	}

	/** An object reference that identifies the parent physical component (e.g., Tray, CRU, etc.) of the object containing the Location attribute. */
	@io.swagger.annotations.ApiModelProperty(value ="An object reference that identifies the parent physical component (e.g., Tray, CRU, etc.) of the object containing the Location attribute." , required = true)
	@XmlElement(required = true)
	private ObjectReference locationParent;

	/** @return An object reference that identifies the parent physical component (e.g., Tray, CRU, etc.) of the object containing the Location attribute. */
	public ObjectReference getLocationParent() {
		return this.locationParent;
	}
	/** @param x An object reference that identifies the parent physical component (e.g., Tray, CRU, etc.) of the object containing the Location attribute. */
	public void setLocationParent(ObjectReference x) {
		this.locationParent = x;
	}

	/** The parent-relative/like-component relative position of the object containing the Location attribute. */
	@io.swagger.annotations.ApiModelProperty(value ="The parent-relative/like-component relative position of the object containing the Location attribute." , required = true)
	@XmlElement(required = true)
	private int locationPosition;

	/** @return The parent-relative/like-component relative position of the object containing the Location attribute. */
	public int getLocationPosition() {
		return this.locationPosition;
	}
	/** @param x The parent-relative/like-component relative position of the object containing the Location attribute. */
	public void setLocationPosition(int x) {
		this.locationPosition = x;
	}

	/** Label associated with the location (i.e., label printed on the canister or the enclosure). */
	@io.swagger.annotations.ApiModelProperty(value ="Label associated with the location (i.e., label printed on the canister or the enclosure)." , required = true)
	@XmlElement(required = true)
	private String label;

	/** @return Label associated with the location (i.e., label printed on the canister or the enclosure). */
	public String getLabel() {
		return this.label;
	}
	/** @param x Label associated with the location (i.e., label printed on the canister or the enclosure). */
	public void setLabel(String x) {
		this.label = x;
	}
}
