package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used to convey information about a power supply component. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(865)
public class PowerSupply implements Serializable,devmgr.api.model.Identifiable {
	public PowerSupply() {
	}

	/** The physical location of the power supply. The parent reference in Location identifies the tray or CRU that physically houses the power supply, and the position field is the parent-relative/like-component relative number of the power supply, starting at one. */
	@io.swagger.annotations.ApiModelProperty(value ="The physical location of the power supply. The parent reference in Location identifies the tray or CRU that physically houses the power supply, and the position field is the parent-relative/like-component relative number of the power supply, starting at one." , required = true)
	@XmlElement(required = true)
	private String powerSupplyRef;

	/** @return The physical location of the power supply. The parent reference in Location identifies the tray or CRU that physically houses the power supply, and the position field is the parent-relative/like-component relative number of the power supply, starting at one. */
	public String getPowerSupplyRef() {
		return this.powerSupplyRef;
	}
	/** @param x The physical location of the power supply. The parent reference in Location identifies the tray or CRU that physically houses the power supply, and the position field is the parent-relative/like-component relative number of the power supply, starting at one. */
	public void setPowerSupplyRef(String x) {
		this.powerSupplyRef = x;
	}

	/** The operation status of the power supply. */
	@io.swagger.annotations.ApiModelProperty(value ="The operation status of the power supply." , required = true)
	@XmlElement(required = true)
	private PowerSupplyStatus status = PowerSupplyStatus.__UNDEFINED;

	/** @return The operation status of the power supply. */
	public PowerSupplyStatus getStatus() {
		return this.status;
	}
	/** @param x The operation status of the power supply. */
	public void setStatus(PowerSupplyStatus x) {
		this.status = x;
	}

	/** The physical location of the power supply. Note that the tray reference identifies the enclosure containing the power supply. For non-XBB controller enclosures, the slot information does not apply. For XBB controller enclosures, the slot information is an ordinal identifier (a value of 1 means the first (left) power supply and a value of 2 means the second (right) power supply). */
	@io.swagger.annotations.ApiModelProperty(value ="The physical location of the power supply. Note that the tray reference identifies the enclosure containing the power supply. For non-XBB controller enclosures, the slot information does not apply. For XBB controller enclosures, the slot information is an ordinal identifier (a value of 1 means the first (left) power supply and a value of 2 means the second (right) power supply)." , required = true)
	@XmlElement(required = true)
	private Location physicalLocation;

	/** @return The physical location of the power supply. Note that the tray reference identifies the enclosure containing the power supply. For non-XBB controller enclosures, the slot information does not apply. For XBB controller enclosures, the slot information is an ordinal identifier (a value of 1 means the first (left) power supply and a value of 2 means the second (right) power supply). */
	public Location getPhysicalLocation() {
		return this.physicalLocation;
	}
	/** @param x The physical location of the power supply. Note that the tray reference identifies the enclosure containing the power supply. For non-XBB controller enclosures, the slot information does not apply. For XBB controller enclosures, the slot information is an ordinal identifier (a value of 1 means the first (left) power supply and a value of 2 means the second (right) power supply). */
	public void setPhysicalLocation(Location x) {
		this.physicalLocation = x;
	}

	/** The part number of the power supply from VPD data. */
	@io.swagger.annotations.ApiModelProperty(value ="The part number of the power supply from VPD data." , required = true)
	@XmlElement(required = true)
	private String partNumber;

	/** @return The part number of the power supply from VPD data. */
	public String getPartNumber() {
		return this.partNumber;
	}
	/** @param x The part number of the power supply from VPD data. */
	public void setPartNumber(String x) {
		this.partNumber = x;
	}

	/** The serial number of the power supply. */
	@io.swagger.annotations.ApiModelProperty(value ="The serial number of the power supply." , required = true)
	@XmlElement(required = true)
	private String serialNumber;

	/** @return The serial number of the power supply. */
	public String getSerialNumber() {
		return this.serialNumber;
	}
	/** @param x The serial number of the power supply. */
	public void setSerialNumber(String x) {
		this.serialNumber = x;
	}

	/** The name of the manufacturer of the power supply. */
	@io.swagger.annotations.ApiModelProperty(value ="The name of the manufacturer of the power supply." , required = true)
	@XmlElement(required = true)
	private String vendorName;

	/** @return The name of the manufacturer of the power supply. */
	public String getVendorName() {
		return this.vendorName;
	}
	/** @param x The name of the manufacturer of the power supply. */
	public void setVendorName(String x) {
		this.vendorName = x;
	}

	/** The date the power supply was manufactured. */
	@io.swagger.annotations.ApiModelProperty(value ="The date the power supply was manufactured." , required = true)
	@XmlElement(required = true)
	private long manufacturerDate;

	/** @return The date the power supply was manufactured. */
	public long getManufacturerDate() {
		return this.manufacturerDate;
	}
	/** @param x The date the power supply was manufactured. */
	public void setManufacturerDate(long x) {
		this.manufacturerDate = x;
	}

	/** The field replaceable unit type of the power supply. */
	@io.swagger.annotations.ApiModelProperty(value ="The field replaceable unit type of the power supply." , required = true)
	@XmlElement(required = true)
	private String fruType;

	/** @return The field replaceable unit type of the power supply. */
	public String getFruType() {
		return this.fruType;
	}
	/** @param x The field replaceable unit type of the power supply. */
	public void setFruType(String x) {
		this.fruType = x;
	}

	/** Reserved */
	@XmlTransient
	private String reserved1;

	/** @return Reserved */
	public String getReserved1() {
		return this.reserved1;
	}
	/** @param x Reserved */
	public void setReserved1(String x) {
		this.reserved1 = x;
	}

	/** Reserved */
	@XmlTransient
	private String reserved2;

	/** @return Reserved */
	public String getReserved2() {
		return this.reserved2;
	}
	/** @param x Reserved */
	public void setReserved2(String x) {
		this.reserved2 = x;
	}

	/** The CRU type of the power supply plus its ready-to-remove attributes, which are based on the CRU type */
	@io.swagger.annotations.ApiModelProperty(value ="The CRU type of the power supply plus its ready-to-remove attributes, which are based on the CRU type" , required = true)
	@XmlElement(required = true)
	private RTRAttributes rtrAttributes;

	/** @return The CRU type of the power supply plus its ready-to-remove attributes, which are based on the CRU type */
	public RTRAttributes getRtrAttributes() {
		return this.rtrAttributes;
	}
	/** @param x The CRU type of the power supply plus its ready-to-remove attributes, which are based on the CRU type */
	public void setRtrAttributes(RTRAttributes x) {
		this.rtrAttributes = x;
	}

	/** The repair policy for the power supply component. */
	@io.swagger.annotations.ApiModelProperty(value ="The repair policy for the power supply component." , required = true)
	@XmlElement(required = true)
	private RepairPolicy repairPolicy;

	/** @return The repair policy for the power supply component. */
	public RepairPolicy getRepairPolicy() {
		return this.repairPolicy;
	}
	/** @param x The repair policy for the power supply component. */
	public void setRepairPolicy(RepairPolicy x) {
		this.repairPolicy = x;
	}

	/** An ASCII character string that identifies the version of the firmware. */
	@io.swagger.annotations.ApiModelProperty(value ="An ASCII character string that identifies the version of the firmware." , required = true)
	@XmlElement(required = true)
	private String firmwareRevision;

	/** @return An ASCII character string that identifies the version of the firmware. */
	public String getFirmwareRevision() {
		return this.firmwareRevision;
	}
	/** @param x An ASCII character string that identifies the version of the firmware. */
	public void setFirmwareRevision(String x) {
		this.firmwareRevision = x;
	}

	/** An integer value that specifies the Manufacturing Device Code. */
	@io.swagger.annotations.ApiModelProperty(value ="An integer value that specifies the Manufacturing Device Code." , required = true)
	@XmlElement(required = true)
	private int manufacturingDeviceCode;

	/** @return An integer value that specifies the Manufacturing Device Code. */
	public int getManufacturingDeviceCode() {
		return this.manufacturingDeviceCode;
	}
	/** @param x An integer value that specifies the Manufacturing Device Code. */
	public void setManufacturingDeviceCode(int x) {
		this.manufacturingDeviceCode = x;
	}
	@Override
	public String getId(){
		return powerSupplyRef;
	}
}
