/******************************************************************************
 * Copyright 2015 NetApp, Inc. All rights reserved.                           *
 *                                                                            *
 * This file is confidential and a trade secret of NetApp, Inc.               *
 * The receipt of or possession of this file does not convey any rights to    *
 * reproduce or disclose its contents or to manufacture, use, or sell         *
 * anything it may describe, in whole, or in part, without the specific       *
 * written consent of NetApp, Inc.                                            *
 ******************************************************************************/

package devmgr.api.symbolutils;

import devmgr.api.rpc.RPCError;

import java.security.GeneralSecurityException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

/**
 * SYMbol Message Authentication Code generator using the legacy SHA-1 digest.
 */
public class SymbolMacSha1 extends SymbolMac{
    private static final String SHA_1_ALGORITHM = "SHA";
    private MessageDigest sha1;
    private byte[] key;


    /**
     * Creates a new SymbolMacSha1.
     *
     * @throws RPCError if an error occurs initializing the digest
     */
    public SymbolMacSha1() throws RPCError {
        try {
            sha1 = MessageDigest.getInstance(SHA_1_ALGORITHM);
        }
        catch (NoSuchAlgorithmException e) {
            // Shouldn't happen - SHA algorithm is required by all Java implementations
            RPCError error = new RPCError(RPCError.ErrorType.AUTH_ALGORITHM);
            error.initCause(e);
            throw error;
        }
    }


    @Override
    public int getOutputSize() { return sha1.getDigestLength(); }


    @Override
    public void setKey(byte[] key) throws RPCError {
        this.key = key;
        sha1.reset();
        sha1.update(key);
    }


    @Override
    public void update(byte[] input, int offset, int length) {
        sha1.update(input, offset, length);
    }


    @Override
    public void digest(byte[] output, int offset) throws RPCError {
        try {
            byte[] result = sha1.digest();
            sha1.update(key);
            sha1.update(result);
            sha1.digest(output, offset, getOutputSize());
        }
        catch (GeneralSecurityException e) {
            RPCError error = new RPCError(RPCError.ErrorType.AUTH_ALGORITHM);
            error.initCause(e);
            throw error;
        }
    }
}
